@@ -284,12 +284,26 @@ class VulnerabilityLocation(object):
         parts = CPE_REGEX.match(cpe_uri)
         version = max_affected_version if max_affected_version else parts.group(3)
         if min_affected_version and max_affected_version:
-            version = min_affected_version + "-" + max_affected_version
+            if min_affected_version == "*":
+                version = "<=" + max_affected_version
+            elif max_affected_version == "*":
+                version = ">=" + min_affected_version
+            else:
+                version = min_affected_version + "-" + max_affected_version
         if parts:
             return VulnerabilityLocation(cpe_uri, parts.group(2), version)
         else:
             return None
 
+    def __str__(self):
+        return json.dumps(
+            {
+                "cpe_uri": str(self.cpe_uri),
+                "package": str(self.package),
+                "version": str(self.version),
+            }
+        )
+
 
 class VulnerabilityOccurrence:
     """Class to represent an occurrence of a vulnerability
